==> openfermioncirq-0.1.1a27-py2-none-any.whl: openfermioncirq/optimization/algorithm_test.py <==
# coding=utf-8
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

from __future__ import with_statement
from __future__ import absolute_import
from typing import Optional

import numpy
import pytest

from openfermioncirq.optimization import BlackBox, OptimizationResult

from openfermioncirq.optimization.algorithm import OptimizationAlgorithm


class ExampleBlackBox(BlackBox):

    @property
    def dimension(self):
        return 2

    def evaluate(self,
                 x):
        return numpy.sum(x**2)


class ExampleAlgorithm(OptimizationAlgorithm):

    def optimize(self,
                 black_box,
                 initial_guess=None,
                 initial_guess_array=None
                 ):
        if initial_guess is None:
            initial_guess = numpy.ones(black_box.dimension)
        if initial_guess_array is None:
            initial_guess_array = numpy.ones(3 * black_box.dimension).reshape(
                    (3, black_box.dimension))
        a = black_box.evaluate(initial_guess)
        b = black_box.evaluate(initial_guess_array[0])
        c = black_box.evaluate(initial_guess_array[1])
        d = black_box.evaluate(initial_guess_array[2])
        return OptimizationResult(optimal_value=min(a, b, c, d),
                                  optimal_parameters=initial_guess,
                                  num_evaluations=1,
                                  cost_spent=0.0,
                                  status=0,
                                  message=u'success')


def test_optimization_algorithm_options():
    algorithm = ExampleAlgorithm()
    assert algorithm.options == {}


def test_optimization_algorithm_optimize():
    black_box = ExampleBlackBox()
    algorithm = ExampleAlgorithm()
    result = algorithm.optimize(black_box)

    numpy.testing.assert_allclose(result.optimal_parameters, numpy.ones(2))
    assert result.optimal_value == 2.0


def test_optimization_algorithm_is_abstract_cant_instantiate():
    with pytest.raises(TypeError):
        _ = OptimizationAlgorithm()


def test_optimization_algorithm_is_abstract_must_implement():
    class Missing(OptimizationAlgorithm):
        pass

    with pytest.raises(TypeError):
        _ = Missing()


def test_optimization_algorithm_is_abstract_can_implement():
    class Included(OptimizationAlgorithm):
        def optimize(self):
            pass

    assert isinstance(Included(), OptimizationAlgorithm)

==> openfermioncirq-0.4.0.dev20190710151023-py2-none-any.whl: openfermioncirq/optimization/algorithm_test.py <==
# coding=utf-8
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

from __future__ import with_statement
from __future__ import absolute_import
import numpy
import pytest

from openfermioncirq.optimization import OptimizationAlgorithm
from openfermioncirq.testing import ExampleAlgorithm, ExampleBlackBox


def test_optimization_algorithm_options():
    algorithm = ExampleAlgorithm()
    assert algorithm.options == {}


def test_optimization_algorithm_optimize():
    black_box = ExampleBlackBox()
    algorithm = ExampleAlgorithm()
    result = algorithm.optimize(black_box)

    assert isinstance(result.optimal_value, float)
    assert isinstance(result.optimal_parameters, numpy.ndarray)


def test_optimization_algorithm_name():
    algorithm = ExampleAlgorithm()
    assert algorithm.name == u'ExampleAlgorithm'


def test_optimization_algorithm_is_abstract_cant_instantiate():
    with pytest.raises(TypeError):
        _ = OptimizationAlgorithm()


def test_optimization_algorithm_is_abstract_must_implement():
    class Missing(OptimizationAlgorithm):
        pass

    with pytest.raises(TypeError):
        _ = Missing()


def test_optimization_algorithm_is_abstract_can_implement():
    class Included(OptimizationAlgorithm):
        def optimize(self):
            pass

    assert isinstance(Included(), OptimizationAlgorithm)
